@@ -18,17 +18,17 @@
 
 Q_DECLARE_METATYPE(ContactActionsSettings::EnumDialPhoneNumberAction)
 
-K_PLUGIN_FACTORY(KCMAkonadiContactActionsFactory, registerPlugin<KCMAkonadiContactActions>();)
+K_PLUGIN_CLASS_WITH_JSON(KCMAkonadiContactActions, "akonadicontact_actions.json")
 
 KCMAkonadiContactActions::KCMAkonadiContactActions(QWidget *parent, const QVariantList &args)
     : KCModule(parent, args)
 {
-    KAboutData *about = new KAboutData(QStringLiteral("kcmakonadicontactactions"),
-                                       i18n("Contact Actions Settings"),
-                                       QString(),
-                                       QString(),
-                                       KAboutLicense::LGPL,
-                                       i18n("(c) 2009 Tobias Koenig"));
+    auto about = new KAboutData(QStringLiteral("kcmakonadicontactactions"),
+                                i18n("Contact Actions Settings"),
+                                QString(),
+                                QString(),
+                                KAboutLicense::LGPL,
+                                i18n("(c) 2009 Tobias Koenig"));
 
     about->addAuthor(i18n("Tobias Koenig"), QString(), QStringLiteral("tokoe@kde.org"));
 
