@@ -6,8 +6,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_CONTACTEDITORDIALOG_H
-#define AKONADI_CONTACTEDITORDIALOG_H
+#pragma once
 
 #include "akonadi-contact_export.h"
 
@@ -158,4 +157,3 @@ private:
 };
 }
 
-#endif
