@@ -6,8 +6,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_CONTACTGROUPEDITORDIALOG_H
-#define AKONADI_CONTACTGROUPEDITORDIALOG_H
+#pragma once
 
 #include "akonadi-contact_export.h"
 
@@ -118,4 +117,3 @@ private:
 };
 }
 
-#endif
