@@ -129,7 +129,7 @@ QString GrantleeContactGroupFormatter::toHtml(HtmlForm form) const
         // we got a contact group with unresolved references -> we have to resolve
         // it ourself.  this shouldn't be the normal case, actually the calling
         // code should pass in an already resolved contact group
-        auto *job = new Akonadi::ContactGroupExpandJob(group);
+        auto job = new Akonadi::ContactGroupExpandJob(group);
         if (job->exec()) {
             group.removeAllContactData();
             const KContacts::Addressee::List lstContacts = job->contacts();
