@@ -6,10 +6,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef CATEGORIESEDITWIDGET_H
-#define CATEGORIESEDITWIDGET_H
-
-#include <QWidget>
+#pragma once
 
 #include <ContactEditor/CategoriesEditAbstractWidget>
 #include <QVariant>
@@ -39,4 +36,3 @@ private:
     Akonadi::TagWidget *const mTagWidget;
 };
 
-#endif
