@@ -6,8 +6,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_STANDARDCONTACTFORMATTER_H
-#define AKONADI_STANDARDCONTACTFORMATTER_H
+#pragma once
 
 #include "akonadi-contact_export.h"
 
@@ -72,4 +71,3 @@ private:
 };
 }
 
-#endif
